@@ -1,6 +1,10 @@
 `plotfoc` <-
 function(MEC)
 {
+oldpar <- par(no.readonly = TRUE)
+      on.exit(par(oldpar))
+    
+    
 par(mfrow=c(3,1))
 
 radiateP(MEC )
@@ -9,7 +13,7 @@ if(length(MEC$PTS)>0)
   {
     focpoint(MEC$PTS$gaz, MEC$PTS$angP,  lab=MEC$PTS$name, UP=MEC$UP)
   }
-# print(paste(" ", "P=", MEC$P$az, MEC$P$dip, "T=", MEC$T$az, MEC$T$dip))
+# message(paste(" ", "P=", MEC$P$az, MEC$P$dip, "T=", MEC$T$az, MEC$T$dip))
 focpoint(MEC$P$az, MEC$P$dip,  lab="P", UP=MEC$UP)
 focpoint(MEC$T$az, MEC$T$dip,  lab="T", UP=MEC$UP)
 
